from setuptools import setup, find_packages

setup(
    name="cdt.ai",
    version="1.0",
    packages=find_packages(),
    install_requires=[
        'scikit-learn',
        'whisper',
        'librosa',
        'opencv-python',
        'easyocr',
        'pydub',
        'moviepy',
        'torch',
        'sentence-transformers',
        'pillow',
        'pdfplumber',
        'PyMuPDF',
        'pandas',
        'numpy',
        'matplotlib',
        'seaborn',
        'regex',
        'tqdm',
        'flask',
        'gensim',
        'fuzzywuzzy',
        'pyyaml',
        'python-magic',  # For MIME type detection (added for file validation)
    ],
    description="Cognitive Data Transformer for text, image, audio, and video processing",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="Tanmay Dumbre",
    author_email="tanmaymdumbrek@gmail.com",
    url="https://github.com/xtechie12345",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
